package no.ntnu.idatt1002.demo.data.recipes;

import java.util.ArrayList;
import java.util.Comparator;
import java.util.List;
import java.util.stream.Collectors;

public class RecipeRegister {

    private final List<Recipe> recipes = new ArrayList<>();


    //TODO: Copy-constructor

    public List<Recipe> getRecipes() {
        return recipes;
    }

    public void addRecipe (Recipe recipe) {
        if(recipes.contains(recipe)) {
            throw new IllegalArgumentException("The recipe already exists in the register."); // Or just replace?
        } else if (recipe == null) {
            throw new NullPointerException("The recipe cannot be null.");
        }
        this.recipes.add(recipe);
    }

    public Recipe getRecipe(String name) {
        return recipes.stream().
                filter((recipe) -> recipe.getName().equals(name))
                        .findFirst().orElse(null);
    }


    public ArrayList<Recipe> pickBestFits(int number, IngredientsAtHand atHand) {
        ArrayList<Recipe> recipes;

        this.recipes.forEach(r -> r.updateIngredientStatus(atHand));

        recipes = this.recipes.stream()
                .sorted(Comparator.comparingInt(Recipe::getMissingIngredients))
                .limit(number).collect(Collectors.toCollection(ArrayList::new));

        return recipes;
    }

}
